==> forms-v5.2.1.tar.gz: forms/l10n/pt_PT.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formulários",
    "{user} has shared the form {formTitle} with you" : "{user} partilhou o formulário   {formTitle} consigo",
    "{user} has shared the form {formTitle} with group {group}" : "{user} partilhou o formulário {formTitle} com o grupo {group}",
    "Anonymous user" : "Utilizador anónimo",
    "A form has been <strong>shared</strong> with you" : "Um formulário foi <strong>partilhado</strong> consigo",
    "Someone <strong>answered</strong> a form" : " Alguém <strong>respondeu</strong>a um formulário ",
    "No" : "Não",
    "Yes" : "Sim",
    "Copy" : "copiar",
    "Anonymous response" : "Resposta anónima",
    "Shared by %s" : "Partilhado por %s",
    "responses" : "Respostas",
    "User display name" : "Nome de apresentação do utilizador",
    "Timestamp" : "Indicador de dia e hora",
    "📝 Simple surveys and questionnaires, self-hosted" : "Formulários e questionários simples, feitos à medida",
    "An error occurred while loading the forms list" : "Um erro ocorreu ao importar a lista de formulários",
    "Form not found" : "Formulário não encontrado",
    "Unable to create a new form" : "Não foi possível criar um novo formulário",
    "Unable to copy form" : "Não foi possível copiar o formulário",
    "New form" : "Novo formulário",
    "Shared with you" : "Partilhado consigo",
    "Loading forms …" : "Carregando formulários",
    "No forms created yet" : "Nenhum formulário ainda criado",
    "Create a form" : "Crie um formulário",
    "Select a form or create a new one" : "Selecione um formulário ou crie um novo",
    "Create new form" : "Crie novo formulário",
    "This form does not exist" : "Este formulário não existe",
    "Form expired" : "Formulário expirou",
    "This form has expired and is no longer taking answers" : "Formulário expirou e não é possível obter mais respostas",
    "Select groups" : "Selecionar grupos",
    "Delete form" : "Apague formulário",
    "Error while deleting {title}" : "Erro ao apagar {title}",
    "Share form" : "Partilhar formulário",
    "Results" : "Resultados",
    "Copy form" : "Copiar formulário",
    "Are you sure you want to delete {title}?" : "Tem a certeza de querer apagar {title}?",
    "Cancel" : "Cancelar",
    "Options" : "Opções",
    "Answer number {index}" : "Resposta número {index}",
    "Error while saving the answer" : "Erro ao guardar a resposta",
    "Delete answer" : "Apague resposta",
    "This question needs a title!" : "Esta pergunta precisa de título",
    "Question number {index}" : "Pergunta número {index}",
    "Title of question number {index}" : "Título da pergunta número {index}",
    "Required" : "Obrigatório",
    "Delete question" : "Apague pergunta",
    "Delete" : "Apagar",
    "Uploading …" : "A carregar ...",
    "A long answer for the question “{text}”" : "Uma resposta longa para a pergunta \"{text}\"",
    "Add \"other\"" : "Adicione \"outra\"",
    "Other:" : "Outra:",
    "Other" : "Outro",
    "Invalid regular expression" : "Expressão regular inválida",
    "A short answer for the question “{text}”" : "Uma resposta curta para a pergunta \"{text}\"",
    "Regular expression for input validation" : "Expressão regular para validação de entrada",
    "No response" : "Nenhuma resposta",
    "Delete this response" : "Apague esta resposta",
    "Expired on {date}" : "Expirou em {date}",
    "Expires on {date}" : "Expira em {date}",
    "never" : "nunca",
    "Store responses anonymously" : "Armazene as respostas anonimamente",
    "Allow multiple responses per person" : "Permitir respostas múltiplas por pessoa",
    "Set expiration date" : "Definir a data de expiração",
    "Close form" : "Fechar formulário",
    "Group" : "Grupo",
    "Share link" : "Partilhar ligação",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Copy embedding code" : "Copiar código embebido",
    "View" : "Ver",
    "Edit" : "Editar",
    "View mode" : "Modo de visualização",
    "Share" : "Partilhar",
    "Responses are anonymous." : "Respostas são anónimas.",
    "An asterisk (*) indicates mandatory questions." : "O asterisco (*) indica perguntas obrigatórias.",
    "There was an error while adding the new question" : "Ocorreu um erro ao adicionar uma nova pergunta",
    "There was an error while removing the question" : "Ocorreu um erro ao remover a pergunta",
    "Error while saving form" : "Erro ao guardar o formulário",
    "Loading {title} …" : "A carregar {title} …",
    "Form title" : "Título do formulário",
    "Description" : "Descrição",
    "Add a question" : "Acrescente uma pergunta",
    "Summary" : "Resumo",
    "Responses" : "Respostas",
    "There was an error while loading the results" : "Ocorreu um erro ao carregar os resultados",
    "Export successful to {file}" : "Exportação realizada para {file}",
    "There was an error, while exporting to Files" : "Ocorreu um erro ao exportar para Ficheiros",
    "There was an error while removing this response" : "Ocorreu um erro ao remover esta resposta",
    "There was an error while removing responses" : "Ocorreu um erro ao remover as respostas",
    "{amount} responses" : "{amount} respostas",
    "Download" : "Transferir",
    "Delete all responses" : "Apagar todas as respostas",
    "Search" : "Pesquisa sobre",
    "Loading responses …" : "Carregando respostas …",
    "No results found" : "No results found",
    "No responses yet" : "Sem respostas ainda",
    "Results of submitted forms will show up here" : "Resultados dos formulários entregues aparecem aqui",
    "Are you sure you want to delete all responses of {title}?" : "Tem a certeza de querer remover todas as respostas de {title}?",
    "Sharing" : "Partilha",
    "Settings" : "Configurações",
    "Abort" : "Abortar",
    "Submit" : "Submeter",
    "Clear" : "Limpar",
    "There was an error submitting the form" : "Ocorreu um erro ao submeter o formulário",
    "Submit form" : "Submeter formulário",
    "Submitting form …" : "Submetendo o formulário …",
    "Thank you for completing the form!" : "Obrigado por ter preenchido o formulário!",
    "You have unsaved changes! Do you still want to leave?" : "Existem alterações que não estão guardadas. Tem a certeza que quer sair?",
    "Error while saving question" : "Erro ao guardar a pergunta",
    "There was an issue deleting this option" : "Ocorreu um problema no apagar desta opção",
    "Form link copied" : "Ligação do formulário copiada",
    "Cannot copy, please copy the link manually" : "Não foi possível copiar, copie a ligação manualmente",
    "No recommendations. Start typing." : "Nenhuma recomendação. Comece a escrever ",
    "No elements found." : "Não foram encontrados elementos.",
    "Checkboxes" : "Caixas de seleção",
    "Checkbox question title" : "Título da pergunta da caixa de verificação",
    "Enter your answer" : "Escreva a sua resposta",
    "This question needs a title and at least one answer!" : "Esta pergunta precisa de um título e pelo menos de uma resposta!",
    "Dropdown" : "Lista de opções",
    "Dropdown question title" : "Título da pergunta com lista de opções",
    "People can pick one option" : "Pessoa pode escolher uma opção",
    "Pick an option" : "Escolha uma opção",
    "File" : "Ficheiro",
    "Short answer" : "Resposta curta",
    "Short answer question title" : "Título da pergunta com resposta curta",
    "People can enter a short answer" : "Pessoa pode escrever uma resposta curta",
    "Long text" : "Texto longo",
    "Long text question title" : "Título da pergunta para texto longo",
    "People can enter a long text" : "Pessoa pode escreve um texto longo",
    "Date" : "Data",
    "Date question title" : "Título da pergunta sobre data",
    "People can pick a date" : "Pessoas podem escolher uma data",
    "Pick a date" : "Escolha uma data",
    "Datetime" : "Data e hora",
    "Datetime question title" : "Título da pergunta sobre data e hora'",
    "People can pick a date and time" : "Pessoas podem escolher data e hora",
    "Pick a date and time" : "Escolha uma data e hora",
    "Time" : "Tempo",
    "Color" : "Cor",
    "Image" : "Imagem",
    "Document" : "Documento",
    "Presentation" : "Apresentação",
    "Spreadsheet" : "Folha de Cálculo",
    "Text" : "Texto",
    "Phone number" : "Número de telefone",
    "Email address" : "Endereço de email"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> forms-v5.2.3.tar.gz: forms/l10n/pt_PT.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formulários",
    "{user} has shared the form {formTitle} with you" : "{user} partilhou o formulário   {formTitle} consigo",
    "{user} has shared the form {formTitle} with group {group}" : "{user} partilhou o formulário {formTitle} com o grupo {group}",
    "Anonymous user" : "Utilizador anónimo",
    "A form has been <strong>shared</strong> with you" : "Um formulário foi <strong>partilhado</strong> consigo",
    "Someone <strong>answered</strong> a form" : " Alguém <strong>respondeu</strong>a um formulário ",
    "No" : "Não",
    "Yes" : "Sim",
    "Copy" : "copiar",
    "Anonymous response" : "Resposta anónima",
    "Shared by %s" : "Partilhado por %s",
    "responses" : "Respostas",
    "User display name" : "Nome de apresentação do utilizador",
    "Timestamp" : "Indicador de dia e hora",
    "📝 Simple surveys and questionnaires, self-hosted" : "Formulários e questionários simples, feitos à medida",
    "An error occurred while loading the forms list" : "Um erro ocorreu ao importar a lista de formulários",
    "Form not found" : "Formulário não encontrado",
    "Unable to create a new form" : "Não foi possível criar um novo formulário",
    "Unable to copy form" : "Não foi possível copiar o formulário",
    "New form" : "Novo formulário",
    "Shared with you" : "Partilhado consigo",
    "No forms created yet" : "Nenhum formulário ainda criado",
    "Create a form" : "Crie um formulário",
    "Select a form or create a new one" : "Selecione um formulário ou crie um novo",
    "Create new form" : "Crie novo formulário",
    "This form does not exist" : "Este formulário não existe",
    "Form expired" : "Formulário expirou",
    "This form has expired and is no longer taking answers" : "Formulário expirou e não é possível obter mais respostas",
    "Select groups" : "Selecionar grupos",
    "Delete form" : "Apague formulário",
    "Error while deleting {title}" : "Erro ao apagar {title}",
    "Share form" : "Partilhar formulário",
    "Results" : "Resultados",
    "Copy form" : "Copiar formulário",
    "Are you sure you want to delete {title}?" : "Tem a certeza de querer apagar {title}?",
    "Cancel" : "Cancelar",
    "Options" : "Opções",
    "Answer number {index}" : "Resposta número {index}",
    "Error while saving the answer" : "Erro ao guardar a resposta",
    "Delete answer" : "Apague resposta",
    "This question needs a title!" : "Esta pergunta precisa de título",
    "Question number {index}" : "Pergunta número {index}",
    "Title of question number {index}" : "Título da pergunta número {index}",
    "Required" : "Obrigatório",
    "Delete question" : "Apague pergunta",
    "Delete" : "Apagar",
    "A long answer for the question “{text}”" : "Uma resposta longa para a pergunta \"{text}\"",
    "Add \"other\"" : "Adicione \"outra\"",
    "Other:" : "Outra:",
    "Other" : "Outro",
    "Invalid regular expression" : "Expressão regular inválida",
    "A short answer for the question “{text}”" : "Uma resposta curta para a pergunta \"{text}\"",
    "Regular expression for input validation" : "Expressão regular para validação de entrada",
    "No response" : "Nenhuma resposta",
    "Delete this response" : "Apague esta resposta",
    "Expired on {date}" : "Expirou em {date}",
    "Expires on {date}" : "Expira em {date}",
    "never" : "nunca",
    "Store responses anonymously" : "Armazene as respostas anonimamente",
    "Allow multiple responses per person" : "Permitir respostas múltiplas por pessoa",
    "Set expiration date" : "Definir a data de expiração",
    "Close form" : "Fechar formulário",
    "Group" : "Grupo",
    "Share link" : "Partilhar ligação",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Copy embedding code" : "Copiar código embebido",
    "View" : "Ver",
    "Edit" : "Editar",
    "View mode" : "Modo de visualização",
    "Share" : "Partilhar",
    "Responses are anonymous." : "Respostas são anónimas.",
    "An asterisk (*) indicates mandatory questions." : "O asterisco (*) indica perguntas obrigatórias.",
    "There was an error while adding the new question" : "Ocorreu um erro ao adicionar uma nova pergunta",
    "There was an error while removing the question" : "Ocorreu um erro ao remover a pergunta",
    "Error while saving form" : "Erro ao guardar o formulário",
    "Form title" : "Título do formulário",
    "Description" : "Descrição",
    "Add a question" : "Acrescente uma pergunta",
    "Summary" : "Resumo",
    "Responses" : "Respostas",
    "There was an error while loading the results" : "Ocorreu um erro ao carregar os resultados",
    "Export successful to {file}" : "Exportação realizada para {file}",
    "There was an error, while exporting to Files" : "Ocorreu um erro ao exportar para Ficheiros",
    "There was an error while removing this response" : "Ocorreu um erro ao remover esta resposta",
    "There was an error while removing responses" : "Ocorreu um erro ao remover as respostas",
    "{amount} responses" : "{amount} respostas",
    "Download" : "Transferir",
    "Delete all responses" : "Apagar todas as respostas",
    "Search" : "Pesquisa sobre",
    "No results found" : "No results found",
    "No responses yet" : "Sem respostas ainda",
    "Results of submitted forms will show up here" : "Resultados dos formulários entregues aparecem aqui",
    "Are you sure you want to delete all responses of {title}?" : "Tem a certeza de querer remover todas as respostas de {title}?",
    "Sharing" : "Partilha",
    "Settings" : "Configurações",
    "Abort" : "Abortar",
    "Submit" : "Submeter",
    "Clear" : "Limpar",
    "There was an error submitting the form" : "Ocorreu um erro ao submeter o formulário",
    "Submit form" : "Submeter formulário",
    "Thank you for completing the form!" : "Obrigado por ter preenchido o formulário!",
    "You have unsaved changes! Do you still want to leave?" : "Existem alterações que não estão guardadas. Tem a certeza que quer sair?",
    "Error while saving question" : "Erro ao guardar a pergunta",
    "There was an issue deleting this option" : "Ocorreu um problema no apagar desta opção",
    "Form link copied" : "Ligação do formulário copiada",
    "Cannot copy, please copy the link manually" : "Não foi possível copiar, copie a ligação manualmente",
    "No recommendations. Start typing." : "Nenhuma recomendação. Comece a escrever ",
    "No elements found." : "Não foram encontrados elementos.",
    "Checkboxes" : "Caixas de seleção",
    "Checkbox question title" : "Título da pergunta da caixa de verificação",
    "Enter your answer" : "Escreva a sua resposta",
    "This question needs a title and at least one answer!" : "Esta pergunta precisa de um título e pelo menos de uma resposta!",
    "Dropdown" : "Lista de opções",
    "Dropdown question title" : "Título da pergunta com lista de opções",
    "People can pick one option" : "Pessoa pode escolher uma opção",
    "Pick an option" : "Escolha uma opção",
    "File" : "Ficheiro",
    "Short answer" : "Resposta curta",
    "Short answer question title" : "Título da pergunta com resposta curta",
    "People can enter a short answer" : "Pessoa pode escrever uma resposta curta",
    "Long text" : "Texto longo",
    "Long text question title" : "Título da pergunta para texto longo",
    "People can enter a long text" : "Pessoa pode escreve um texto longo",
    "Date" : "Data",
    "Date question title" : "Título da pergunta sobre data",
    "People can pick a date" : "Pessoas podem escolher uma data",
    "Pick a date" : "Escolha uma data",
    "Datetime" : "Data e hora",
    "Datetime question title" : "Título da pergunta sobre data e hora'",
    "People can pick a date and time" : "Pessoas podem escolher data e hora",
    "Pick a date and time" : "Escolha uma data e hora",
    "Time" : "Tempo",
    "Color" : "Cor",
    "Image" : "Imagem",
    "Document" : "Documento",
    "Presentation" : "Apresentação",
    "Spreadsheet" : "Folha de Cálculo",
    "Text" : "Texto",
    "Phone number" : "Número de telefone",
    "Email address" : "Endereço de email",
    "Loading forms …" : "Carregando formulários",
    "Uploading …" : "A carregar ...",
    "Loading {title} …" : "A carregar {title} …",
    "Loading responses …" : "Carregando respostas …",
    "Submitting form …" : "Submetendo o formulário …"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
